AlekSIS' calendar system
========================

AlekSIS has a built-in calendar system that bundles all time-related information
in one place. This includes:

- Birthdays of persons
- Holidays
- Personal events (cf. :ref:`core-personal-event`)

Other apps may add more calendars, such as timetables. You can access the calendar
overview frontend via the ``Calendar`` menu point.

.. image:: ../_static/calendar_overview.png
  :width: 100%
  :alt: Active school term selection menu

In addition to the options of changing between different views (day, week, month)
and of selecting the date range you want to see, you can select which calendars
should be shown using the ``My Calendars`` menu. Clicking on an event opens a dialog
showing additional information about the given event, such as an event description.
The calendar information shown to you is personalized: For example, users can only see
the birthdays of persons they have access to.

Clicking on the button indicated by three points next to each calendar item in the
``My calendar`` menu gives you the option to download the respective calendar as an
.ics file. This format is supported by nearly every calendar client (e. g. Thunderbird).
Opening it with such a client allows you to view the selected calendar locally.
